@@ -1,9 +1,12 @@
 import os
 import time
+import logging
 from functools import partial
 from collections import defaultdict, deque
 import pytorchrl as prl
 
+logger = logging.getLogger(__name__)
+
 
 class Learner:
     """
@@ -36,6 +39,8 @@ class Learner:
         # Record starting time
         self.start = time.time()
 
+        logger.warning("Created Learner.")
+
     def step(self):
         """Takes a logical synchronous optimization step."""
 
@@ -82,7 +87,6 @@ class Learner:
         m = {}
 
         def include_info(key):
-            m[key] = {}
             for k, v in self.metrics[key].items():
                 m[os.path.join(key, k)] = sum(v) / len(v)
 
@@ -154,3 +158,7 @@ class Learner:
         fname = os.path.join(self.log_dir, fname)
         save_name = self.update_worker.save_model(fname)
         return save_name
+
+    def stop(self):
+        """Stop all threads."""
+        self.update_worker.stop()
