@@ -1,9 +1,7 @@
-import os
-import ray
 import time
 import torch
 import numpy as np
-from collections import deque, defaultdict
+from collections import defaultdict
 
 import pytorchrl as prl
 from pytorchrl.scheme.utils import check_message, pack
@@ -13,7 +11,6 @@ from pytorchrl.scheme.base.worker import Worker as W
 class CWorker(W):
     """
      Worker class handling data collection.
-
     This class wraps an actor instance, a storage class instance and a
     train and a test vector environments. It collects data samples, sends
     them and and evaluates network versions.
@@ -44,7 +41,7 @@ class CWorker(W):
         Initial model weights.
     device : str
         "cpu" or specific GPU "cuda:number`" to use for computation.
-
+        
     Attributes
     ----------
     index_worker : int
@@ -245,7 +242,7 @@ class CWorker(W):
             # Define transition sample
             transition = prl.DataTransition(
                 self.obs, self.rhs, self.done, act, reward,
-                obs2, rhs2, done2)._asdict()
+                obs2, rhs2, done2, episode_infos)._asdict()
             transition.update(algo_data)
 
             # Store transition in buffer
@@ -317,6 +314,8 @@ class CWorker(W):
         """
         Update the worker actor version with provided weights.
 
+        Parameters
+        ----------
         actor_weights : dict of tensors
             Dict containing actor weights to be set.
         """
@@ -380,3 +379,10 @@ class CWorker(W):
                 new_component_component = new_component_factory(self.device)
             setattr(self, component_name, new_component_component)
 
+    def stop(self):
+        """Stop all processes"""
+        self.envs_train.close()
+        try:
+            self.envs_test.close()
+        except Exception:
+            pass
