@@ -203,25 +203,37 @@ class GWorker(W):
 
         # except (StopIteration, AttributeError):
         except Exception:
-            if self.col_communication == prl.SYNC:
-                self.collector.step()
 
-            data, self.info = self.collector.queue.get()
+            # Check if more batches with the same data are required
+            can_reuse_data = hasattr(self.algo, "reuse_data")
+            if not can_reuse_data or not self.algo.reuse_data:
 
-            # Time data processing and calculate collection-to-processing time ratio
-            if not self.processing_time_start:
-                self.processing_time_start = time.time()
+                # Get new data
+                if self.col_communication == prl.SYNC:
+                    self.collector.step()
+                data, self.info = self.collector.queue.get()
+
+                # Calculate and log data collection-to-processing time ratio
+                if not self.processing_time_start:
+                    self.processing_time_start = time.time()
+                else:
+                    self.info[prl.TIME][prl.PROCESSING] = time.time() - self.processing_time_start
+                    self.info[prl.TIME][prl.CPRATIO] = (
+                        self.info[prl.TIME][prl.COLLECTION] / self.num_collection_workers) / self.info[prl.TIME][
+                        prl.PROCESSING]
+                    self.processing_time_start = time.time()
+
+                # Proprocess new data
+                self.storage.insert_data_slice(data)
+                self.storage.before_gradients()
             else:
-                self.info[prl.TIME][prl.PROCESSING] = time.time() - self.processing_time_start
-                self.info[prl.TIME][prl.CPRATIO] = \
-                    (self.info[prl.TIME][prl.COLLECTION] / self.num_collection_workers
-                     ) / self.info[prl.TIME][prl.PROCESSING]
-                self.processing_time_start = time.time()
+                # Only record collected samples once
+                self.info[prl.NUMSAMPLES] = 0
 
-            self.storage.insert_data_slice(data)
-            self.storage.before_gradients()
+            # Genarate batches
             self.batches = self.storage.generate_batches(
-                self.algo.num_mini_batch, self.algo.mini_batch_size,
+                self.algo.num_mini_batch,
+                self.algo.mini_batch_size,
                 self.algo.num_epochs)
             self.next_batch = self.batches.__next__()
 
@@ -353,7 +365,7 @@ class GWorker(W):
         """
 
         torch.save(self.local_worker.actor.state_dict(), fname + ".tmp")
-        os.rename(fname + '.tmp', fname)
+        os.replace(fname + '.tmp', fname)
         save_name = fname + ".{}".format(self.local_worker.actor_version)
         copy2(fname, save_name)
         return save_name
@@ -363,7 +375,9 @@ class GWorker(W):
 
         if hasattr(self, "collector"):
             self.collector.stopped = True
+        self.local_worker.stop()
         for e in self.remote_workers:
+            e.stop.remote()
             e.terminate_worker.remote()
 
 
